Sprite

Struct Sprite 

pub struct Sprite {
    pub transform: Transform,
    /* private fields */
}

Fields

transform: Transform

Implementations

Source

impl Sprite

pub fn new( albedo: TextureInput, height: TextureInput, roughness: TextureInput, normal: NormalInput, program: &mut LumenpyxProgram, transform: Transform, ) -> (Sprite, TextureHandle, TextureHandle, TextureHandle, TextureHandle)

returns a tuple of the sprite and the texture handles for albedo, height, roughness, and normal textures in that order

pub fn set_shadow_strength(&mut self, strength: f32)

pub fn free_all_textures(&self, program: &mut LumenpyxProgram)